Seantis Kantonsrat
==================

Specialized type and custom organisations for the Kantonsrat of Zug. If you 
have never heard of a Kantonsrat, this is in no way meant for you.

Requirements
------------

-  Python 2.7
-  Plone 4.3+
-  Linux / Posix ( Windows may or may not work )

Build Status
------------

.. image:: https://travis-ci.org/seantis/seantis.kantonsrat.png
  :target: https://travis-ci.org/seantis/seantis.kantonsrat
  :alt: Build Status

Coverage
--------

.. image:: https://coveralls.io/repos/seantis/seantis.kantonsrat/badge.png?branch=master
  :target: https://coveralls.io/r/seantis/seantis.kantonsrat?branch=master
  :alt: Project Coverage

Latests PyPI Release
--------------------
.. image:: https://pypip.in/v/seantis.kantonsrat/badge.png
  :target: https://crate.io/packages/seantis.kantonsrat
  :alt: Latest PyPI Release

License
-------
seantis.kantonsrat is released under GPL v2
